#!/bin/bash -l

# This script is executed on the remote system at which the simulation will happen
# and will be used if the initial conditions are in this same remote system.
IC_DATA_IS_LOCAL=%SIMULATION.INITIAL_CONDITIONS.LOCAL%


if [ "${IC_DATA_IS_LOCAL}" != "True" ]; then
  # Get some variables provided by autosubmit.
  WORKDIR=%HPCROOTDIR%
  STARTDATE=%SDATE%
  HPCUSER=%HPCUSER%
  HPCHOST=%HPCHOST%

  . ${WORKDIR}/proj/platforms/common/spack_utils.sh
  load_spack "%spack.init%" "%spack.root%" "%spack.url%" "%spack.branch%" "%spack.externals%" "%spack.compiler%" "%spack.disable_local_config%" "%spack.user_cache_path%" "%spack.user_config_path%" "%spack.upstreams%"

  # Load icon module
  spack load --first eccodes
  spack load --first dwd-icon-tools

  # Set environment variable for eccodes-dwd definitions:
  source ${WORKDIR}/eccodes_defs.env

  # Define date directory, create it and go there
  COMMON_DATE_FOLDER=${WORKDIR}/${STARTDATE}/inidata

  # Exploit the number from the member name
  INITIAL_CONDITIONS_PARENT_FOLDER=%SIMULATION.INITIAL_CONDITIONS.PARENT_FOLDER%
  INITIAL_CONDITIONS_PATH=${INITIAL_CONDITIONS_PARENT_FOLDER}/${STARTDATE:0:10}

  AN_SOURCE=$(find ${INITIAL_CONDITIONS_PATH} -name "an_R19B07.*00_an.*" | sort -n )
  AN_INC_SOURCE=$(find ${INITIAL_CONDITIONS_PATH} -name "an_R19B07.*00_inc.*" | sort -n )
  FG_SOURCE=$(find ${INITIAL_CONDITIONS_PATH} -name "fc_R19B07.*5500.*" | sort -n )

  # Find files
  # if [ -z "${AN_SOURCE}" ]; then
  #   echo "Analysis file for date ${STARTDATE} not found!"
  #   exit 1
  # fi

  if [ -z "${AN_INC_SOURCE}" ]; then
    echo "Analysis increment file for date ${STARTDATE} not found!"
    exit 1
  fi


  if [ -z "${FG_SOURCE}" ]; then
    echo "FG file for date ${STARTDATE} not found!"
    exit 1
  fi


  # Check if we copy the initial conditions from the local system or the remote one
  # Create member folder and go there
  mkdir -p ${COMMON_DATE_FOLDER}
  cd ${COMMON_DATE_FOLDER} || exit

  # Save filenames to be used later by other scripts.
  echo "${AN_SOURCE}" > an_file.txt
  echo "${AN_INC_SOURCE}" > an_inc_file.txt
  echo "${FG_SOURCE}" > fg_file.txt

  # Copy the first-guess and analysis files.
  #rsync -v --files-from=an_file.txt / "${COMMON_DATE_FOLDER}"
  #rsync -v --files-from=an_inc_file.txt / "${COMMON_DATE_FOLDER}"
  #rsync -v --files-from=fg_file.txt / "${COMMON_DATE_FOLDER}"

  # Create links for the detected analysis and first-guess files
  awk '{print $1}' an_file.txt | xargs -I[] ln -sf [] .
  awk '{print $1}' an_inc_file.txt | xargs -I[] ln -sf [] .
  awk '{print $1}' fg_file.txt | xargs -I[] ln -sf [] .

  grib_set -s stepRange=0,dataTime=$((${STARTDATE:8:10}*100)),dataDate=${STARTDATE:0:8} "%simulation.lbc_hhl_filepath%" ${COMMON_DATE_FOLDER}/HHL.grib 
  grib_set -s stepRange=0,dataTime=$((${STARTDATE:8:10}*100)),dataDate=${STARTDATE:0:8} "%simulation.lbc_wz_filepath%" ${COMMON_DATE_FOLDER}/WZ.grib 

  if [ "%simulation.lbc_wz_attach%" = "True" ]; then
    grib_copy "%simulation.lbc_wz_filepath%" ${COMMON_DATE_FOLDER}/WZ.grib 
  fi

  if [ ! -f "${COMMON_DATE_FOLDER}/HHL.grib"  ]; then
    echo "Invariant height field HHL.grib for date ${STARTDATE} not created!"
    exit 1
  fi
  # Change permissions to read only.
  #chmod 440 ./*
fi